@@ -1,7 +1,7 @@
 package Finance::Currency::Convert::BCA;
 
-our $DATE = '2018-07-10'; # DATE
-our $VERSION = '0.153'; # VERSION
+our $DATE = '2018-07-15'; # DATE
+our $VERSION = '0.154'; # VERSION
 
 use 5.010001;
 use strict;
@@ -68,7 +68,7 @@ sub get_currencies {
         my $tx = $ua->get($url);
         unless ($tx->success) {
             my $err = $tx->error;
-            return [500, "Can't retrieve BCA page ($url): $err->{message}"];
+            return [500, "Can't retrieve URL $url: $err->{message}"];
         }
         $page = $tx->res->body;
     }
@@ -83,7 +83,7 @@ sub get_currencies {
             my $row = $row0->find("td")->map(
                 sub { $_->text })->to_array;
             #use DD; dd $row;
-            next unless $row->[0] =~ /\A[A-Z]{3}\z/;
+            return unless $row->[0] =~ /\A[A-Z]{3}\z/;
             $currencies{$row->[0]} = {
                 sell_er  => Parse::Number::ID::parse_number_id(text=>$row->[1]),
                 buy_er   => Parse::Number::ID::parse_number_id(text=>$row->[2]),
@@ -139,7 +139,6 @@ sub get_currencies {
 
     $mtime = min(grep {defined} ($mtime_er, $mtime_ttc, $mtime_bn));
 
-    # XXX parse update dates (mtime_er, mtime_ttc, mtime_bn)
     [200, "OK", {
         mtime => $mtime,
         mtime_er => $mtime_er,
@@ -246,7 +245,7 @@ Finance::Currency::Convert::BCA - Convert currency using BCA (Bank Central Asia)
 
 =head1 VERSION
 
-This document describes version 0.153 of Finance::Currency::Convert::BCA (from Perl distribution Finance-Currency-Convert-BCA), released on 2018-07-10.
+This document describes version 0.154 of Finance::Currency::Convert::BCA (from Perl distribution Finance-Currency-Convert-BCA), released on 2018-07-15.
 
 =head1 SYNOPSIS
 
